/**
 * Vezbe 5
 * Preduslov predavanja zakljucno sa Mape i skupovi
 * Klasa Menjacnica modelira rad menjacnice
 */
import java.util.HashMap;
import java.util.Date;     // predstavlja klasu za rad sa datumima
public class Menjacnica {
    
    private String ime, adresa;  // opisna polja
    private HashMap<String, Kurs> kursnaLista; // vazeca kursna lista
    private Date datumAzuriranja; // datum poslednje promene u listi               
    /**
     * Kreira menjacnicu
     */
    public Menjacnica(String ime, String adresa){
        this.ime = ime; this.adresa = adresa;
        kursnaLista = new HashMap<String, Kurs>();
    }
    /**
     * Azurira kompletan kurs za neku valutu (ako ne postoji, ubacuje)
     */
    public void azurirajValutu(String valuta, double kupovni, double prodajni){
        kursnaLista.put( valuta, new Kurs(valuta, kupovni, prodajni) );
        datumAzuriranja = new Date(); // poziv konstruktora kreira  
                                      // datumski objekat sa tekucim datumom
    }
    
    public void azurirajValutu2(String valuta, double kupovni, double prodajni){
        
        Kurs k = kursnaLista.get(valuta);
        if(k == null) {
            k = new Kurs(valuta, kupovni, prodajni);
            kursnaLista.put(valuta, k);
        } else {
            k.postaviKupovni(kupovni);
            k.postaviProdajni(prodajni);
        }
        
        datumAzuriranja = new Date(); // poziv konstruktora kreira  
                                      // datumski objekat sa tekucim datumom
    }
    
    
    
    /**
     * Azurira kupovni kurs neke valute
     */
    public void azurirajKupovni(String valuta, double kupovni){
        Kurs k = kursnaLista.get(valuta);
        if(k != null){
            k.postaviKupovni(kupovni);
            datumAzuriranja = new Date();
        } else{ 
            System.out.println("Trazena valuta ne postoji");
        }
    }
    /**
     * Azurira prodajni kurs neke valute
     */
    public void azurirajProdajni(String valuta, double prodajni){
        Kurs k = kursnaLista.get(valuta);
        if(k != null){
            k.postaviKupovni(prodajni);
            datumAzuriranja = new Date();
        } else{ 
            System.out.println("Trazena valuta ne postoji");
        }
    }
    /**
     * Vraca kurs za valutu
     */
    public Kurs dajKurs(String valuta){ return kursnaLista.get(valuta); }
    /**
     * Ispisuje kursnu listu
     */
    public void info(){ 
        System.out.print("Kursna lista za: " ); // ostaje u istom redu
        System.out.println(datumAzuriranja);    // ispisuje tekst reprezentaciju datuma
        for(String val : kursnaLista.keySet()){
            Kurs k = kursnaLista.get(val);
            System.out.println(k.opis());
        }
    }
    /**
     * Izbacuje valutu iz kursne liste
     */
    public void izbaciValutu(String valuta){
        kursnaLista.remove(valuta);
        datumAzuriranja = new Date();
    }
    /**
     * Vraca iznos u nekoj valuti za date dinare prema tekucem kursu
     */
    public double kupiValutu(double iznosDin, String valuta){
        Kurs k = kursnaLista.get(valuta);
        if( k != null ){
            return iznosDin / k.dajProdajni();
        } else{ 
            System.out.println("Vracam datih " + iznosDin + " dinara");
            return iznosDin;
        }
    }
    /**
     * Vraca iznos u dinarima za iznos specificirane valute po tekucem kursu
     */
    public double kupiDinare(double iznosVal, String valuta){
        Kurs k = kursnaLista.get(valuta);
        if( k != null ){
            return k.dajKupovni() * iznosVal;
        } else{ 
            System.out.println("Vracam datih " + iznosVal + " u " + valuta);
            return iznosVal;
        }
    }
}
