/**
 * Vezbe 4
 * Neophodna predavanja zakljucno sa: Grupisanje objekata - nizovi
 * Klasa Registrator modelira registrator sa proizvoljnim brojem listova.
 * Podrazumeva se da se novi listovi dodaju na kraj  
 */
import java.util.ArrayList;
public class Registrator {

    private ArrayList<List> listovi; // listovi u registratoru
    private String nalepnica; // tekst na korici registratora
    
    /**
     * Kreira prazan registrator sa nalepnicom
     */
    public Registrator(String nalepnica){
        this.nalepnica = nalepnica;
        listovi = new ArrayList<>();
    }
    /**
     * Daje vrednost nalepnice 
     */
    public String dajNalepnicu(){ return nalepnica; }
    /**
     * Postavlja/menja nalepnicu
     */
    public void zalepi(String nalepnica) { this.nalepnica = nalepnica;}
    /**
     * Vraca tekuci broj listova
     */
    public int brojListova() { return listovi.size(); }
    /**
     * Ubacuje list na kraj (kao poslednji)
     */
    public void ubaci(List l){
        listovi.add(l);
        l.postaviBrojLista(listovi.size());
    }
    /**
     * Ubacuje list na poziciju i (broj lista treba da je i)
     */
    public void ubaci(List list, int i){
        if(i < 1 || i > brojListova() + 1) {
            System.out.println("Van dozvoljenog opsega!");
            return;
        }
        list.postaviBrojLista(i);
        listovi.add(i-1, list); // list sa brojem i ima indeks i-1
        for(int ind = i; i < listovi.size(); i++) {
            listovi.get(i).postaviBrojLista(i+1);
        }
    }
    /**
     * Izbaci list sa brojem i (izmi ga iz registratora)
     */
    public List izbaci(int i){
        if(i < 1 || i > brojListova()) {
            System.out.println("Van dozvoljenog opsega!");
            return null;
        }
        List l = listovi.remove(i-1);
        for(int ind = i; i < listovi.size(); i++) {
            listovi.get(i).postaviBrojLista(i-1);
        }
        l.postaviBrojLista(0);
        return l;
    }
    /**
     * Ispisuje sadrzaj registratora
     */
    public void ispisi() {
        System.out.println("Registrator: " + nalepnica);
        System.out.println("Broj listova: " + brojListova());
        for(List l : listovi){
            System.out.println(l.opis());
            System.out.println("-----------------------");
        }
    }
    /**
     * Vraca listove sa trazenim tekstom
     */
    public ArrayList<List> trazi(String txt){
        ArrayList<List> rezultat = new ArrayList<>();
        for(List l : listovi){
            if(l.sadrzi(txt)){
                rezultat.add(l);
            }
        }
        return rezultat;
    }    
    /**
     * Static test metoda koja testira rad klase
     */
    public static void test(){
        Registrator r = new Registrator("OOP");
        List l1 = new List("Prvi list");
        List l2 = new List("Drugi list");
        List l3 = new List("Treci list");
        r.ubaci(l1); r.ubaci(l3); r.ubaci(l2, 2);
        r.ispisi();
        r.izbaci(3);
        r.ispisi();
    }
    
}